#include "ds3231.h"

DS3231::DS3231(int addDS3231) // Constructeur de la classe DS3231 avec comme parametre l'adresse de la RTC
{
    I2C = new Ci2c('1', addDS3231);
}

byte DS3231::decToBcd(byte val) // Convertie du decimale en binaire codé decimale
{
    return ((val/10*16) + (val%10));
}

byte DS3231::bcdToDec(byte val) // Convertie le binaire codé decimale en decimale
{
    return ((val/16*10) + (val%16));
}

byte DS3231::readTemp() // Permet de lire la temperature du capteur
{
    byte temp[2];

    this->bufferI2C[0] = 0x11;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(temp, 2);

    return temp[0];
}

byte DS3231::getSeconde() // Permet de lire les secondes
{
    byte seconde[1];

    this->bufferI2C[0] = 0x00;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(seconde, 1);

    return bcdToDec(seconde[0]);


}

void DS3231::setSeconde(byte seconde) // Permet d'ecrire les secondes
{
    seconde = decToBcd(seconde);
}

byte DS3231::getMinute() // Permet de lire les mintutes
{
    byte minute[1];

    this->bufferI2C[0] = 0x01;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(minute, 1);

    return bcdToDec(minute[0]);
}

void DS3231::setMinute(byte minute) // Permet d'ecrire les minutes
{
    minute = decToBcd(minute);
}

byte DS3231::getHeure() // Permet de lire l'heure
{
    byte heure[1];

    this->bufferI2C[0] = 0x02;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(heure, 1);

    if((heure[0] & 0x60) == 0x60)
    {
        return bcdToDec(heure[0] ^ 0x60);
    }
    else if((heure[0] & 0x40) == 0x40)
    {
        return bcdToDec(heure[0] ^ 0x40);
    }
    else
    {
        return bcdToDec(heure[0]);
    }
}

void DS3231::setHeure(byte heure, byte format, QString ampm) // Permet d'ecrire l'heure en 12h et am ou pm ou 24h 
{
    this->bufferI2C[0] = 0x02;

    if(format == 12)
    {
        if(heure > 12)
        {
            heure = heure - 12;
        }

        if((ampm == "AM") | (ampm == "am"))
        {
            this->bufferI2C[1] = (decToBcd(heure) | 0x40);
        }
        else if((ampm == "PM") | (ampm == "pm"))
        {
            this->bufferI2C[1] = (decToBcd(heure) | 0x60);
        }
    }
    else if(format == 24)
    {
        this->bufferI2C[1] = decToBcd(heure);
    }

    I2C->writeToI2C(this->bufferI2C, 2);
}

QString DS3231::getJour() // Permet de lire le jour
{
    QString jours[7] = {"Lundi","Mardi", "Mercredi", "Jeudi", "Vendredi", "Samedi", "Dimanche"};

    byte jour[1];

    this->bufferI2C[0] = 0x03;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(jour, 1);

    return jours[bcdToDec(jour[0]) - 1];
}

void DS3231::setJour(byte jour) // Permet d'ecrire le jour
{
    jour = decToBcd(jour);

    this->bufferI2C[0] = 0x03;
    this->bufferI2C[1] = jour;

    I2C->writeToI2C(this->bufferI2C, 2);
}

byte DS3231::getDate() // Permet de lire la date
{
    byte date[1];

    this->bufferI2C[0] = 0x04;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(date, 1);

    return bcdToDec(date[0]);
}

void DS3231::setDate(byte date) // Permet d'ecrire la date
{
    date = decToBcd(date);

    this->bufferI2C[0] = 0x04;
    this->bufferI2C[1] = date;

    I2C->writeToI2C(this->bufferI2C, 2);
}

byte DS3231::getMois() // Permet de lire le mois
{
    byte mois[1];

    this->bufferI2C[0] = 0x05;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(mois, 1);

    return bcdToDec(mois[0]);
}

void DS3231::setMois(byte mois) // Permet d'ecrire le mois 
{
    mois = decToBcd(mois);

    this->bufferI2C[0] = 0x05;
    this->bufferI2C[1] = mois;

    I2C->writeToI2C(this->bufferI2C, 2);
}

int DS3231::getAnnee() // Permet de lire l'annee
{
    byte annee[1];

    this->bufferI2C[0] = 0x06;

    I2C->writeToI2C(this->bufferI2C, 1);

    I2C->readFromI2C(annee, 1);

    return (bcdToDec(annee[0]) + 2000);
}

void DS3231::setAnnee(byte annee) // Permet d'ecrire l'annee
{
    annee = decToBcd(annee);

    this->bufferI2C[0] = 0x06;
    this->bufferI2C[1] = annee;

    I2C->writeToI2C(this->bufferI2C, 2);
}
