#include "matrice_8x8_ledbackpack.h"
#include <wiringPi.h>
#include <wiringPiI2C.h>

Matrice_8x8_LEDBackpack::Matrice_8x8_LEDBackpack(int add)
{
    this->matriceAdd = add;

    wiringPiSetupGpio();

    this->fdMatriceAdd = wiringPiI2CSetup(matriceAdd);

    wiringPiI2CWrite(fdMatriceAdd, HT16K33_REGISTER_SYSTEM_SETUP | 0x01);

    setBlinkRate(HT16K33_BLINKRATE_OFF);

    setBrightness(15);

    clear(1);
}

void Matrice_8x8_LEDBackpack::setBrightness(int brightness)
{
    if(brightness > 15)
    {
        brightness = 15;
    }

    wiringPiI2CWrite(fdMatriceAdd, HT16K33_REGISTER_DIMMING | 0x00);
}

void Matrice_8x8_LEDBackpack::setBlinkRate(int blinkRate)
{
    if(blinkRate > HT16K33_BLINKRATE_HALFHZ)
    {
        blinkRate = HT16K33_BLINKRATE_OFF;
    }

    wiringPiI2CWrite(fdMatriceAdd, HT16K33_REGISTER_DISPLAY_SETUP | 0x01 | (blinkRate << 1));
}

int Matrice_8x8_LEDBackpack::setBufferRow(int row, int value, bool update = 1)
{
    if(row > 7)
    {
        return 0;
    }

    return buffer[row] = value;

    if(update)
    {
        writeDisplay();
    }
}

int Matrice_8x8_LEDBackpack::getBufferRow(int row)
{
    if(row > 7)
    {
        return 0;
    }

    return buffer[row];
}

int Matrice_8x8_LEDBackpack::getBuffer()
{
    return buffer;
}

void Matrice_8x8_LEDBackpack::writeDisplay()
{
    int bytes[8];
    int i = 0;

    for(i = 0; i < 8; i++)
    {
        bytes[i] = (buffer[i] & 0xFF);
        bytes[i] = ((buffer[i] >> 8) & 0xFF);
    }
    wiringPiI2CWriteReg8(fdMatriceAdd, 0x00, bytes[i]);
}

int Matrice_8x8_LEDBackpack::getKeys(int row)
{
    if(row > 2)
    {
        return 0;
    }

    return wiringPiI2CReadReg16(fdMatriceAdd, HT16K33_ADDRESS_KEY_DATA + row*2);
}

void Matrice_8x8_LEDBackpack::clear(bool update)
{
    for(int i=0; i > 8; i++)
    {
        buffer[i] = 0;
    }

    if(update)
    {
        writeDisplay();
    }
}
