#include "i2c_afficheur_4x20.h"

I2C_Afficheur_4x20::I2C_Afficheur_4x20(int lcdAddress, QString database, QString hostname, QString linkbase, QString password, QString user)
{
    I2C = new Ci2c('1', lcdAddress);

    this->basedata = database;
    this->namehost = hostname;
    this->link = linkbase;
    this->pass = password;
    this->username = user;
}

void I2C_Afficheur_4x20::lcdInit()
{
    this->enLight = 0x00;
    wirteLcd(0x03, 0);
    wirteLcd(0x03, 0);
    wirteLcd(0x03, 0);
    wirteLcd(0x02, 0);
    wirteLcd((LCD_FUNCTIONSET | LCD_2LINE | LCD_5x8DOTS | LCD_4BITMODE),0);
    wirteLcd((LCD_DISPLAYCONTROL | LCD_DISPLAYON),0);
    wirteLcd((LCD_CLEARDISPLAY),0);
    wirteLcd((LCD_ENTRYMODESET | LCD_ENTRYLEFT),0);
    usleep(200);
}

void I2C_Afficheur_4x20::wirteLcd(byte cmd, byte mode)
{
    write4bits(mode | (cmd & 0xF0));
    write4bits(mode | ((cmd << 4) & 0xF0));
}

void I2C_Afficheur_4x20::write4bits(byte data)
{
    writeCmd(data | enLight);
    wirteStrob(data);
}

void I2C_Afficheur_4x20::wirteStrob(byte data)
{
    writeCmd(data | En | enLight);
    usleep(200);
    writeCmd(((data & ~En) | enLight));
    usleep(200);
}

void I2C_Afficheur_4x20::writeCmd(byte cmd)
{
    //wiringPiI2CWrite(addrI2C, cmd);
    byte buffer[1];

    buffer[0] = cmd;

    I2C->writeToI2C(buffer, 1);

    usleep(200);
}

void I2C_Afficheur_4x20::writeLcdDisplay(QString text, int line) // Ecrit sur l'afficheur
{
    switch(line)
    {
        case 1:
        wirteLcd(0x80, 0);
        break;
        case 2 :
        wirteLcd(0xC0, 0);
        break;
        case 3:
        wirteLcd(0x94, 0);
        break;
        case 4:
        wirteLcd(0xD4, 0);
        break;
    }

    for(byte i=0; i < text.length(); i++)
    {
        wirteLcd((text[i].toAscii()), 1);
    }
}

void I2C_Afficheur_4x20::lcdClear() // Efface l'affcheur
{
    wirteLcd(LCD_CLEARDISPLAY, 0);
    wirteLcd(LCD_RETURNHOME, 0);
}

void I2C_Afficheur_4x20::displayOn()    // Permet de preparer l'alumage du BACKLIGHT
{
    this->enLight = 0x08;
}

void I2C_Afficheur_4x20::displayOff() // Permet d'eteindre et d'effacer l'afficheur
{
    this->enLight = 0x00;
    wirteLcd(LCD_CLEARDISPLAY, 0);
    wirteLcd(LCD_RETURNHOME, 0);
}

void I2C_Afficheur_4x20::connexionBDD() // Connexion a la base de donée
{
    bdd = QSqlDatabase::addDatabase(this->basedata);

    bdd.setHostName(this->namehost);
    bdd.setDatabaseName(this->link);
    bdd.setPassword(this->pass);
    bdd.setUserName(this->username);

    if(bdd.open())
    {
        this->querydb = new QSqlQuery(bdd);
    }
}

void I2C_Afficheur_4x20::checkAffichage()
{
    QString text[4];
    int ligne[4];
    int nb = 0;
    bool ok;

    connexionBDD();

    if(querydb->exec("SELECT * FROM informations"))
    {
       while(querydb->next())   // Recuperes les informations de la BDD
        {
           if(querydb->value(1).toString().length() > 0)    // Verifie si il y a un mot
            {
                text[nb] = querydb->value(0).toString();
                ligne[nb] = querydb->value(1).toInt(&ok);
                nb++;
            }
        }

        if(nb > 0)
        {
            lcdClear();    // netoie l'afficheur
            displayOn();   // alume le BACKLIGHT

            for(int i = 0; i < nb; i++)
            {
                writeLcdDisplay(text[i], ligne[i]);
            }
        }
        else    // Si il n'y a rien a afficher alors on etein l'afficheur
        {
            displayOff();  // netoie l'afficheur et eteint le BACKLIGHT
        }
        bdd.close();
     }
}
