#include "mainwindow.h"
#include "ui_mainwindow.h"

#define adresse 0x20    // adresse de l'afficheur

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    connexionBDD();

    lcd = new I2C_Afficheur_4x20(adresse);  //Crée un nouvelle objet lcd avec comme parametre l'adresse

    lcd->lcdInit(); // Initialisation de l'afficheur

    T1=new QTimer(this);
    T1->setInterval(15000);
    connect (T1,SIGNAL(timeout()), this, SLOT(sltOnTimer()));
    T1->start();

    ui->btn_update->setEnabled(false);

    querydb->prepare("UPDATE test SET ok = :value");
    querydb->bindValue(":value", 1);
    querydb->exec();
    this->first = 1;
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::connexionBDD()
{
    bdd = QSqlDatabase::addDatabase("QSQLITE");

    bdd.setHostName("localhost");
    bdd.setDatabaseName("/home/pi/bdd/URBACO.db");
    bdd.setPassword("");
    bdd.setUserName("root");

    if(bdd.open())
    {
        this->querydb = new QSqlQuery(bdd);
    }
}

void MainWindow::sltOnTimer()
{
    QString text[4];
    int ligne[4];
    int nb = 0;
    bool ok;

    if(querydb->exec("SELECT * FROM test"))
    {
        querydb->next();
        this->test = querydb->value(0).toBool();
    }
    if(this->test == this->first)
    {
        if(querydb->exec("SELECT * FROM informations"))
        {
            while(querydb->next())
            {
                if(querydb->value(0).toString().length() > 0)
                {
                    text[nb] = querydb->value(0).toString();
                    ligne[nb] = querydb->value(1).toInt(&ok);
                    nb++;
                }
            }

            if(nb > 0)
            {
                lcd->lcdClear();    // netoie l'afficheur
                lcd->displayOn();   // alume le BACKLIGHT

                for(int i = 0; i < nb; i++)
                {
                    lcd->writeLcdDisplay(text[i], ligne[i]);
                }
            }
            else    // Si il n'y a rien a afficher alors on etein l'afficheur
            {
                lcd->displayOff();  // netoie l'afficheur et eteint le BACKLIGHT
            }

            querydb->prepare("UPDATE test SET ok = :value");
            querydb->bindValue(":value", 0);
            querydb->exec();
        }
    }
}

void MainWindow::on_btn_get_clicked()
{
    int nb = 0;

    querydb->exec("SELECT * FROM informations");

    while(querydb->next())
    {
        this->text[nb] = querydb->value(0).toString();
        nb++;
    }

    ui->lineEdit_1->setText(this->text[0]);
    ui->lineEdit_2->setText(this->text[1]);
    ui->lineEdit_3->setText(this->text[2]);
    ui->lineEdit_4->setText(this->text[3]);

    ui->btn_update->setEnabled(true);
}

void MainWindow::on_btn_update_clicked()
{
    if(ui->lineEdit_1->text() != this->text[0])
    {
        querydb->prepare("UPDATE informations SET texte = :text1 WHERE ligne = 1");
        querydb->bindValue(":text1", ui->lineEdit_1->text());
        querydb->exec();
    }
    if(ui->lineEdit_2->text() != this->text[1])
    {
        querydb->prepare("UPDATE informations SET texte = :text2 WHERE ligne = 2");
        querydb->bindValue(":text2", ui->lineEdit_2->text());
        querydb->exec();
    }
    if(ui->lineEdit_3->text() != this->text[2])
    {
        querydb->prepare("UPDATE informations SET texte = :text3 WHERE ligne = 3");
        querydb->bindValue(":text3", ui->lineEdit_3->text());
        querydb->exec();
    }
    if(ui->lineEdit_4->text() != this->text[3])
    {
        querydb->prepare("UPDATE informations SET texte = :text4 WHERE ligne = 4");
        querydb->bindValue(":text4", ui->lineEdit_4->text());
        querydb->exec();
    }

    querydb->prepare("UPDATE test SET ok = :value");
    querydb->bindValue(":value", 1);
    querydb->exec();

    ui->btn_update->setEnabled(false);
}
